# name, ver, rel are passed in from Makefile so we only have to set them one place
%define name lsb-test-cpp-t2c
%define ver 5.0.0
%define rel 0.20190202.1

# LSB Compliant packages require the following in ~/.rpmmacros
#%_binary_payload   w9.gzdio

Summary: LSB Cpp-T2C Test Suite
Vendor: ISPRAS
Name: %{name}
Version: %{ver}
Release: %{rel}
Source: %{name}-%{version}.src.tgz
License: GPL
URL: http://www.linux-foundation.org/en/Downloads
Group: Development/Tools
Buildroot: %{_builddir}/%{name}-root
AutoReqProv: no
Requires: lsb-tet3-lite >= 3.7
BuildRequires: lsb-tet3-lite-devel, lsb-build-c++

%description
The test suite for libstdcxx created using the T2C 
("Template-to-C") framework.

%prep
if [ ! -x /opt/lsb/bin/lsbc++ ] ; then
    printf "lsbc++ not found although it is required to build the tests\n"
    exit 1
fi

%setup -q

%build
export LSBCC_BESTEFFORT=1
# build T2C framework components first
chmod -R +rx .
CUR_DIR=`pwd`
export T2C_ROOT="${CUR_DIR}/t2c_framework" 
t2c_framework/t2c/build.sh > build.log
cd cpp-t2c 
./build_all.sh 

%install

#install the test suites
T2C_ROOT=${RPM_BUILD_ROOT}/opt/lsb/test/cpp-t2c
rm -rf ${T2C_ROOT}
rm -rf ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
mkdir -p ${T2C_ROOT}
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}

cd cpp-t2c
for TEST_SUITE in "*-t2c"
do 
    cp -r ${TEST_SUITE} ${T2C_ROOT}
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/src ${T2C_ROOT}/${TEST_SUITE}/gen_tests ${T2C_ROOT}/${TEST_SUITE}/clean ${T2C_ROOT}/${TEST_SUITE}/*.cfg
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/testdata/testdata_src
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/tests/Makefile ${T2C_ROOT}/${TEST_SUITE}/tests/*.mk
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/tests/*/Makefile
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/tests/*/*.c
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/tests/*/*.cpp
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/include
    rm -rf ${T2C_ROOT}/${TEST_SUITE}/doc
done
cd ..

install -d ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
cp cpp-t2c/README  ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
cp cpp-t2c/LICENSE ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
cp cpp-t2c/run_tests.sh cpp-t2c/pre-run.sh cpp-t2c/tet_code cpp-t2c/tet_scen cpp-t2c/tetexec.cfg ${T2C_ROOT}
cp -r cpp-t2c/locales ${T2C_ROOT}

%files
%defattr(777,tester,tester)
/opt/lsb/test/cpp-t2c
%dir /opt/lsb/doc/%{name}
/opt/lsb/doc/%{name}/*

%pre
PATH=/usr/sbin:$PATH

# Create 'tester' group 
# echo
# echo "Attempting to create group 'tester'"
groupadd tester >/dev/null 2>&1 || true

# if [ $? = 0 ]; then
#    echo "If you later want to delete this group, run the following command (as root):"
#    echo "    groupdel tester"
# fi

# Create a new user ('tester') if it doesn't exist.
#echo
#echo "Checking if there is a user named 'tester' on this system..."
id tester >/dev/null 2>&1

if [ $? -ne 0 ]; then 
#    echo "User 'tester' does not exist. Attempting to create it...".
    useradd -d /home/tester -s /bin/sh -c "cpp-t2c tester login" tester -m -g tester >/dev/null 2>&1
    
    if [ $? = 0 ]; then
#        echo "User 'tester' was created successfully."
#        echo "If you later want to delete this user account, run the following command (as root):"
#        echo "    userdel -rf tester"
#        echo "Here 'userdel' is assumed to be somewhere in your path"
        echo
    else
        echo "Failed to add user 'tester'."
        echo "To be able to run the tests you should add this user manually."
        exit 1
    fi
fi

# usermod -G tester tester >/dev/null 2>&1 || true
# End of the preinstall script.

%post
RESULT=0

#install custom locales 
#echo
#echo "Installing custom locales. You may need root privileges to do this."
/opt/lsb/test/cpp-t2c/locales/install_locale.sh

if [ $? -gt 0 ] ; then
    RESULT=1
    echo "Failed to install custom locales."
    echo "Some of the tests (e.g. the tests for Localization Library in libstdcxx) may not work properly."
fi

# print out a message
#echo
#echo "LSB cpp-t2c Test Suite has been installed to"
#echo "/opt/lsb/test/cpp-t2c."
#if [ $RESULT -ne 0 ]; then
#    echo
#    echo "There were warnings."
#fi
# End of the postinstall script.

%preun
if [ "$1" = "0" -o "$1" = "remove" ] ; then 
    # remove
    rm -rf /opt/lsb/test/cpp-t2c/results
    rm -rf /opt/lsb/test/cpp-t2c/tet_tmp_dir

    #uninstall custom locales 
#    echo
#    echo "Unnstalling custom locales. You may need root privileges to do this."
    /opt/lsb/test/cpp-t2c/locales/uninstall_locale.sh > /dev/null 2>&1
fi
# End of the preuninstall script.

%clean
if [ ! -z "${RPM_BUILD_ROOT}"  -a "${RPM_BUILD_ROOT}" != "/" ]; then
    rm -rf ${RPM_BUILD_ROOT}
fi
